==> pandoc-citeproc-0.16.2-108-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-citeproc
version: 0.16.2
id: pandoc-citeproc-0.16.2-7hUnSaAYRLD41LwXk7wYGJ
key: pandoc-citeproc-0.16.2-7hUnSaAYRLD41LwXk7wYGJ
license: BSD-3-Clause
maintainer: jgm@berkeley.edu
author: John MacFarlane, Andrea Rossato
homepage: https://github.com/jgm/pandoc-citeproc
synopsis: Supports using pandoc with citeproc
description:
    The pandoc-citeproc library supports automatic
    generation of citations and a bibliography in pandoc
    documents using the Citation Style Language (CSL)
    macro language. More details on CSL can be found at
    <http://citationstyles.org/>.
    .
    In addition to a library, the package includes
    an executable, pandoc-citeproc, which works as a pandoc
    filter and also has a mode for converting bibliographic
    databases into CSL JSON and pandoc YAML metadata formats.
    .
    pandoc-citeproc originated as a fork of Andrea
    Rossato'\''s citeproc-hs.
category: Text
abi: 1de1755cd2c19d8524f5ea1fa636b46a
exposed: True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style
hidden-modules: Text.CSL.Util Paths_pandoc_citeproc
                Text.CSL.Compat.Pandoc
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-citeproc-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-citeproc-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-citeproc
hs-libraries: HSpandoc-citeproc-0.16.2-7hUnSaAYRLD41LwXk7wYGJ
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ directory-1.3.3.0
    filepath-1.4.2.1 hs-bibutils-6.7.0.0-FZxrSZg5Y3h1rDYhDXLOxx
    mtl-2.2.2 network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    pandoc-2.7.3-AqtWRE9JQfFJ8kRyRPInPK
    pandoc-types-1.17.6-1vlaY2HgDGZK9PuQHq7zzg parsec-3.1.13.0
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
    split-0.2.3.3-6ARGTwZCeo0EpQtAl0OgPz
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    tagsoup-0.14.8-DGG11JtHSmWKGlohPlXRaq text-1.2.3.1
    text-icu-0.7.0.1-JejFEKt5vpa5ez9tKsOTMT time-1.8.0.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    xml-conduit-1.8.0.1-ILhpnjWW5MmEW3BGQ7MomI
    yaml-0.11.1.2-EtnoPovHIFR52d1kEzbYMn
haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html: /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-citeproc-0.16.2-110-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-citeproc
version: 0.16.2
id: pandoc-citeproc-0.16.2-DOycw8ATV9u8NjEpKEBrP7
key: pandoc-citeproc-0.16.2-DOycw8ATV9u8NjEpKEBrP7
license: BSD-3-Clause
maintainer: jgm@berkeley.edu
author: John MacFarlane, Andrea Rossato
homepage: https://github.com/jgm/pandoc-citeproc
synopsis: Supports using pandoc with citeproc
description:
    The pandoc-citeproc library supports automatic
    generation of citations and a bibliography in pandoc
    documents using the Citation Style Language (CSL)
    macro language. More details on CSL can be found at
    <http://citationstyles.org/>.
    .
    In addition to a library, the package includes
    an executable, pandoc-citeproc, which works as a pandoc
    filter and also has a mode for converting bibliographic
    databases into CSL JSON and pandoc YAML metadata formats.
    .
    pandoc-citeproc originated as a fork of Andrea
    Rossato'\''s citeproc-hs.
category: Text
abi: 5cfc5daddcdb875a75c5d447273af379
exposed: True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style
hidden-modules: Text.CSL.Util Paths_pandoc_citeproc
                Text.CSL.Compat.Pandoc
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-citeproc-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-citeproc-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-citeproc
hs-libraries: HSpandoc-citeproc-0.16.2-DOycw8ATV9u8NjEpKEBrP7
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ directory-1.3.3.0
    filepath-1.4.2.1 hs-bibutils-6.7.0.0-FZxrSZg5Y3h1rDYhDXLOxx
    mtl-2.2.2 network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    pandoc-2.7.3-JwJCjgazxcgDuBKtqrWfEw
    pandoc-types-1.17.6-1vlaY2HgDGZK9PuQHq7zzg parsec-3.1.13.0
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
    split-0.2.3.3-6ARGTwZCeo0EpQtAl0OgPz
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    tagsoup-0.14.8-DGG11JtHSmWKGlohPlXRaq text-1.2.3.1
    text-icu-0.7.0.1-JejFEKt5vpa5ez9tKsOTMT time-1.8.0.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    xml-conduit-1.8.0.1-JucBthwjmTJ1BsBOjwopk
    yaml-0.11.1.2-GcrC5gzJJYy7QaoJJ7PWya
haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html: /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
